@@ -71,7 +71,7 @@ where
         info!("📦 Creating container for {} ...", store.name());
         let config = container::Config {
             image: Some(store.image()),
-            env: Some(store.envs()),
+            env: Some(store.envs()?),
             cmd: store.entry_cmd(),
             host_config: Some(models::HostConfig {
                 auto_remove: Some(true),
@@ -144,7 +144,7 @@ where
         info!("💫 Resetting {} ...", store.name());
         // sometimes `init_cmd` fails even after `ping_cmd` succeeded so we may retry
         while let Err(e) = exec(self, &store.full_name(), store.reset_cmd()).await {
-            info!("⌛ {} may not ready", store.name());
+            info!("⌛ {} may not be ready yet ...", store.name());
             debug!("init {} failed: {}", store.name(), e);
             if !retry {
                 return Err(e);
